@@ -3,7 +3,7 @@
  *
  * https://www.onlyoffice.com/
  *
- * Version: 9.0.0 (build:172)
+ * Version: 9.1.0 (build:173)
  */
 
 (function(window,undefined){function internal_isLocal(){if(window.navigator&&window.navigator.userAgent.toLowerCase().indexOf("ascdesktopeditor")<0)return false;if(window.location&&window.location.protocol=="file:")return true;if(window.document&&window.document.currentScript&&0==window.document.currentScript.src.indexOf("file:///"))return true;return false}function locateFile(path){if(Module["locateFile"])return Module["locateFile"](path,scriptDirectory);return scriptDirectory+path}function updateMemoryViews(){var b=
@@ -30,8 +30,8 @@ if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_viiiiiii(index,a1,a2,a3,a4,a5
 a2,a3,a4,a5,a6,a7,a8,a9)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_iiiidddd(index,a1,a2,a3,a4,a5,a6,a7){var sp=stackSave();try{return getWasmTableEntry(index)(a1,a2,a3,a4,a5,a6,a7)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_iiidddd(index,a1,a2,a3,a4,a5,a6){var sp=stackSave();try{return getWasmTableEntry(index)(a1,a2,a3,a4,a5,a6)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_di(index,a1){var sp=stackSave();
 try{return getWasmTableEntry(index)(a1)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_iid(index,a1,a2){var sp=stackSave();try{return getWasmTableEntry(index)(a1,a2)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_vidi(index,a1,a2,a3){var sp=stackSave();try{getWasmTableEntry(index)(a1,a2,a3)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_iidd(index,a1,a2,a3){var sp=stackSave();try{return getWasmTableEntry(index)(a1,
 a2,a3)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_iiiiiidd(index,a1,a2,a3,a4,a5,a6,a7){var sp=stackSave();try{return getWasmTableEntry(index)(a1,a2,a3,a4,a5,a6,a7)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_iidddddd(index,a1,a2,a3,a4,a5,a6,a7){var sp=stackSave();try{return getWasmTableEntry(index)(a1,a2,a3,a4,a5,a6,a7)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_viidd(index,a1,a2,a3,a4){var sp=stackSave();
-try{getWasmTableEntry(index)(a1,a2,a3,a4)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_iiidd(index,a1,a2,a3,a4){var sp=stackSave();try{return getWasmTableEntry(index)(a1,a2,a3,a4)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_viiiddiidd(index,a1,a2,a3,a4,a5,a6,a7,a8,a9){var sp=stackSave();try{getWasmTableEntry(index)(a1,a2,a3,a4,a5,a6,a7,a8,a9)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_viddddiii(index,
-a1,a2,a3,a4,a5,a6,a7,a8){var sp=stackSave();try{getWasmTableEntry(index)(a1,a2,a3,a4,a5,a6,a7,a8)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_vidd(index,a1,a2,a3){var sp=stackSave();try{getWasmTableEntry(index)(a1,a2,a3)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_viidi(index,a1,a2,a3,a4){var sp=stackSave();try{getWasmTableEntry(index)(a1,a2,a3,a4)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_viidiii(index,
+try{getWasmTableEntry(index)(a1,a2,a3,a4)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_iiidd(index,a1,a2,a3,a4){var sp=stackSave();try{return getWasmTableEntry(index)(a1,a2,a3,a4)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_viiiddiidd(index,a1,a2,a3,a4,a5,a6,a7,a8,a9){var sp=stackSave();try{getWasmTableEntry(index)(a1,a2,a3,a4,a5,a6,a7,a8,a9)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_viddddiiii(index,
+a1,a2,a3,a4,a5,a6,a7,a8,a9){var sp=stackSave();try{getWasmTableEntry(index)(a1,a2,a3,a4,a5,a6,a7,a8,a9)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_vidd(index,a1,a2,a3){var sp=stackSave();try{getWasmTableEntry(index)(a1,a2,a3)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_viidi(index,a1,a2,a3,a4){var sp=stackSave();try{getWasmTableEntry(index)(a1,a2,a3,a4)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_viidiii(index,
 a1,a2,a3,a4,a5,a6){var sp=stackSave();try{getWasmTableEntry(index)(a1,a2,a3,a4,a5,a6)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_viiiiidd(index,a1,a2,a3,a4,a5,a6,a7){var sp=stackSave();try{getWasmTableEntry(index)(a1,a2,a3,a4,a5,a6,a7)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_vid(index,a1,a2){var sp=stackSave();try{getWasmTableEntry(index)(a1,a2)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_iiiiid(index,
 a1,a2,a3,a4,a5){var sp=stackSave();try{return getWasmTableEntry(index)(a1,a2,a3,a4,a5)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_fiii(index,a1,a2,a3){var sp=stackSave();try{return getWasmTableEntry(index)(a1,a2,a3)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_diii(index,a1,a2,a3){var sp=stackSave();try{return getWasmTableEntry(index)(a1,a2,a3)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_iiiiiiiiiiii(index,
 a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11){var sp=stackSave();try{return getWasmTableEntry(index)(a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_viiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15){var sp=stackSave();try{getWasmTableEntry(index)(a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15)}catch(e){stackRestore(sp);if(e!==e+0)throw e;_setThrew(1,0)}}function invoke_viid(index,a1,a2,a3){var sp=stackSave();try{getWasmTableEntry(index)(a1,
@@ -76,10 +76,10 @@ var WEEKDAYS=["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Satur
 date.tm_yday+7-date.tm_wday;return leadingNulls(Math.floor(days/7),2)},"%V":function(date){var val=Math.floor((date.tm_yday+7-(date.tm_wday+6)%7)/7);if((date.tm_wday+371-date.tm_yday-2)%7<=2)val++;if(!val){val=52;var dec31=(date.tm_wday+7-date.tm_yday-1)%7;if(dec31==4||dec31==5&&isLeapYear(date.tm_year%400-1))val++}else if(val==53){var jan1=(date.tm_wday+371-date.tm_yday)%7;if(jan1!=4&&(jan1!=3||!isLeapYear(date.tm_year)))val=1}return leadingNulls(val,2)},"%w":function(date){return date.tm_wday},
 "%W":function(date){var days=date.tm_yday+7-(date.tm_wday+6)%7;return leadingNulls(Math.floor(days/7),2)},"%y":function(date){return(date.tm_year+1900).toString().substring(2)},"%Y":function(date){return date.tm_year+1900},"%z":function(date){var off=date.tm_gmtoff;var ahead=off>=0;off=Math.abs(off)/60;off=off/60*100+off%60;return(ahead?"+":"-")+String("0000"+off).slice(-4)},"%Z":function(date){return date.tm_zone},"%%":function(){return"%"}};pattern=pattern.replace(/%%/g,"\x00\x00");for(rule in EXPANSION_RULES_2)if(pattern.includes(rule))pattern=
 pattern.replace(new RegExp(rule,"g"),EXPANSION_RULES_2[rule](date));pattern=pattern.replace(/\0\0/g,"%");var bytes=intArrayFromString(pattern,false);if(bytes.length>maxsize)return 0;writeArrayToMemory(bytes,s);return bytes.length-1};var _strftime_l=function(s,maxsize,format,tm,loc){return _strftime(s,maxsize,format,tm)};var wasmTableMirror=[];var wasmTable;var getWasmTableEntry=function(funcPtr){var func=wasmTableMirror[funcPtr];if(!func){if(funcPtr>=wasmTableMirror.length)wasmTableMirror.length=
-funcPtr+1;wasmTableMirror[funcPtr]=func=wasmTable.get(funcPtr)}return func};var wasmImports={v:___cxa_begin_catch,x:___cxa_end_catch,a:___cxa_find_matching_catch_2,k:___cxa_find_matching_catch_3,V:___cxa_rethrow,B:___cxa_throw,ga:___cxa_uncaught_exceptions,d:___resumeException,T:___syscall_fcntl64,qa:___syscall_fstat64,sa:___syscall_ioctl,na:___syscall_lstat64,oa:___syscall_newfstatat,U:___syscall_openat,ja:___syscall_rmdir,pa:___syscall_stat64,ka:___syscall_unlinkat,ta:__emscripten_get_now_is_monotonic,
-ha:__emscripten_throw_longjmp,K:_abort,ua:_emscripten_date_now,va:_emscripten_memcpy_js,ia:_emscripten_resize_heap,la:_environ_get,ma:_environ_sizes_get,C:_exit,M:_fd_close,ra:_fd_read,ca:_fd_seek,S:_fd_write,y:invoke_di,Q:invoke_diii,R:invoke_fiii,r:invoke_i,b:invoke_ii,ya:invoke_iid,o:invoke_iidd,J:invoke_iidddddd,f:invoke_iii,xa:invoke_iiidd,za:invoke_iiidddd,e:invoke_iiii,O:invoke_iiiidddd,j:invoke_iiiii,fa:invoke_iiiiid,n:invoke_iiiiii,_:invoke_iiiiiidd,s:invoke_iiiiiii,z:invoke_iiiiiiii,E:invoke_iiiiiiiii,
-I:invoke_iiiiiiiiiiii,P:invoke_iiiiiiiiiiiiiii,ba:invoke_jiiii,m:invoke_v,i:invoke_vi,wa:invoke_vid,u:invoke_vidd,Z:invoke_viddddiii,h:invoke_vidi,c:invoke_vii,da:invoke_viid,p:invoke_viidd,Y:invoke_viidi,X:invoke_viidiii,Ba:invoke_viiffffffi,aa:invoke_viiffffi,g:invoke_viii,N:invoke_viiiddiidd,D:invoke_viiiffffffi,A:invoke_viiiffffi,w:invoke_viiiffi,l:invoke_viiii,q:invoke_viiiii,W:invoke_viiiiidd,G:invoke_viiiiii,t:invoke_viiiiiii,L:invoke_viiiiiiii,Aa:invoke_viiiiiiiii,F:invoke_viiiiiiiiii,H:invoke_viiiiiiiiiiiiiii,
-$:_llvm_eh_typeid_for,ea:_strftime_l};var wasmExports=createWasm();var ___wasm_call_ctors=function(){return(___wasm_call_ctors=wasmExports["Da"])()};var _malloc=Module["_malloc"]=function(a0){return(_malloc=Module["_malloc"]=wasmExports["Fa"])(a0)};var _free=Module["_free"]=function(a0){return(_free=Module["_free"]=wasmExports["Ga"])(a0)};var ___errno_location=function(){return(___errno_location=wasmExports["__errno_location"])()};var _ASC_FT_Malloc=Module["_ASC_FT_Malloc"]=function(a0){return(_ASC_FT_Malloc=
+funcPtr+1;wasmTableMirror[funcPtr]=func=wasmTable.get(funcPtr)}return func};var wasmImports={v:___cxa_begin_catch,y:___cxa_end_catch,a:___cxa_find_matching_catch_2,k:___cxa_find_matching_catch_3,U:___cxa_rethrow,A:___cxa_throw,fa:___cxa_uncaught_exceptions,d:___resumeException,S:___syscall_fcntl64,pa:___syscall_fstat64,ra:___syscall_ioctl,ma:___syscall_lstat64,na:___syscall_newfstatat,T:___syscall_openat,ia:___syscall_rmdir,oa:___syscall_stat64,ja:___syscall_unlinkat,sa:__emscripten_get_now_is_monotonic,
+ga:__emscripten_throw_longjmp,K:_abort,ta:_emscripten_date_now,ua:_emscripten_memcpy_js,ha:_emscripten_resize_heap,ka:_environ_get,la:_environ_sizes_get,C:_exit,M:_fd_close,qa:_fd_read,ba:_fd_seek,R:_fd_write,w:invoke_di,P:invoke_diii,Q:invoke_fiii,r:invoke_i,b:invoke_ii,xa:invoke_iid,o:invoke_iidd,J:invoke_iidddddd,f:invoke_iii,wa:invoke_iiidd,ya:invoke_iiidddd,e:invoke_iiii,za:invoke_iiiidddd,j:invoke_iiiii,ea:invoke_iiiiid,n:invoke_iiiiii,Z:invoke_iiiiiidd,s:invoke_iiiiiii,B:invoke_iiiiiiii,E:invoke_iiiiiiiii,
+I:invoke_iiiiiiiiiiii,O:invoke_iiiiiiiiiiiiiii,aa:invoke_jiiii,m:invoke_v,i:invoke_vi,va:invoke_vid,u:invoke_vidd,Y:invoke_viddddiiii,h:invoke_vidi,c:invoke_vii,ca:invoke_viid,p:invoke_viidd,X:invoke_viidi,W:invoke_viidiii,Ba:invoke_viiffffffi,$:invoke_viiffffi,g:invoke_viii,N:invoke_viiiddiidd,D:invoke_viiiffffffi,z:invoke_viiiffffi,x:invoke_viiiffi,l:invoke_viiii,q:invoke_viiiii,V:invoke_viiiiidd,G:invoke_viiiiii,t:invoke_viiiiiii,L:invoke_viiiiiiii,Aa:invoke_viiiiiiiii,F:invoke_viiiiiiiiii,H:invoke_viiiiiiiiiiiiiii,
+_:_llvm_eh_typeid_for,da:_strftime_l};var wasmExports=createWasm();var ___wasm_call_ctors=function(){return(___wasm_call_ctors=wasmExports["Da"])()};var _malloc=Module["_malloc"]=function(a0){return(_malloc=Module["_malloc"]=wasmExports["Fa"])(a0)};var _free=Module["_free"]=function(a0){return(_free=Module["_free"]=wasmExports["Ga"])(a0)};var ___errno_location=function(){return(___errno_location=wasmExports["__errno_location"])()};var _ASC_FT_Malloc=Module["_ASC_FT_Malloc"]=function(a0){return(_ASC_FT_Malloc=
 Module["_ASC_FT_Malloc"]=wasmExports["Ha"])(a0)};var _ASC_FT_Free=Module["_ASC_FT_Free"]=function(a0){return(_ASC_FT_Free=Module["_ASC_FT_Free"]=wasmExports["Ia"])(a0)};var _ASC_FT_Init=Module["_ASC_FT_Init"]=function(){return(_ASC_FT_Init=Module["_ASC_FT_Init"]=wasmExports["Ja"])()};var _ASC_FT_Done_FreeType=Module["_ASC_FT_Done_FreeType"]=function(a0){return(_ASC_FT_Done_FreeType=Module["_ASC_FT_Done_FreeType"]=wasmExports["Ka"])(a0)};var _ASC_FT_Set_TrueType_HintProp=Module["_ASC_FT_Set_TrueType_HintProp"]=
 function(a0,a1){return(_ASC_FT_Set_TrueType_HintProp=Module["_ASC_FT_Set_TrueType_HintProp"]=wasmExports["La"])(a0,a1)};var _ASC_FT_Open_Face=Module["_ASC_FT_Open_Face"]=function(a0,a1,a2,a3){return(_ASC_FT_Open_Face=Module["_ASC_FT_Open_Face"]=wasmExports["Ma"])(a0,a1,a2,a3)};var _ASC_FT_Done_Face=Module["_ASC_FT_Done_Face"]=function(a0){return(_ASC_FT_Done_Face=Module["_ASC_FT_Done_Face"]=wasmExports["Na"])(a0)};var _ASC_FT_SetCMapForCharCode=Module["_ASC_FT_SetCMapForCharCode"]=function(a0,a1){return(_ASC_FT_SetCMapForCharCode=
 Module["_ASC_FT_SetCMapForCharCode"]=wasmExports["Oa"])(a0,a1)};var _ASC_FT_GetFaceInfo=Module["_ASC_FT_GetFaceInfo"]=function(a0){return(_ASC_FT_GetFaceInfo=Module["_ASC_FT_GetFaceInfo"]=wasmExports["Pa"])(a0)};var _ASC_FT_GetFaceMaxAdvanceX=Module["_ASC_FT_GetFaceMaxAdvanceX"]=function(a0){return(_ASC_FT_GetFaceMaxAdvanceX=Module["_ASC_FT_GetFaceMaxAdvanceX"]=wasmExports["Qa"])(a0)};var _ASC_FT_GetKerningX=Module["_ASC_FT_GetKerningX"]=function(a0,a1,a2){return(_ASC_FT_GetKerningX=Module["_ASC_FT_GetKerningX"]=
