@@ -3,7 +3,7 @@
  *
  * http://www.onlyoffice.com 
  *
- * Version: 9.0.0 (build:172)
+ * Version: 9.1.0 (build:173)
  */
 
 
@@ -188,7 +188,7 @@
                             view: {
                                 navigation: false/true // navigation button in de
                             } / false / true, // view tab
-                            save: false/true // save button on toolbar in 
+                            save: false/true // save button on toolbar in
                         } / false / true, // use instead of customization.toolbar,
                         header: {
                             users: false/true // users list button
@@ -277,7 +277,8 @@
                     showHorizontalScroll: true/false, //  show/hide scroll in the spreadsheet editor by default
                     startFillingForm: {
                         text: 'Share & collect' // caption of the start filling button, used for pdf-forms
-                    }
+                    },
+                    suggestFeature: true/false
                 },
                  coEditing: {
                      mode: 'fast', // <coauthoring mode>, 'fast' or 'strict'. if 'fast' and 'customization.autosave'=false -> set 'customization.autosave'=true. 'fast' - default for editor
@@ -515,7 +516,7 @@
 
                 if (typeof _config.document.fileType === 'string' && _config.document.fileType != '') {
                     _config.document.fileType = _config.document.fileType.toLowerCase();
-                    var type = /^(?:(xls|xlsx|ods|csv|gsheet|xlsm|xlt|xltm|xltx|fods|ots|xlsb|sxc|et|ett|numbers)|(pps|ppsx|ppt|pptx|odp|gslides|pot|potm|potx|ppsm|pptm|fodp|otp|sxi|dps|dpt|key|odg)|(pdf|djvu|xps|oxps)|(doc|docx|odt|gdoc|txt|rtf|mht|htm|html|mhtml|epub|docm|dot|dotm|dotx|fodt|ott|fb2|xml|oform|docxf|sxw|stw|wps|wpt|pages|hwp|hwpx|md)|(vsdx|vssx|vstx|vsdm|vssm|vstm))$/
+                    var type = /^(?:(xls|xlsx|ods|csv|gsheet|xlsm|xlt|xltm|xltx|fods|ots|xlsb|sxc|et|ett|numbers)|(pps|ppsx|ppt|pptx|odp|gslides|pot|potm|potx|ppsm|pptm|fodp|otp|sxi|dps|dpt|key|odg)|(pdf|djvu|xps|oxps)|(doc|docx|odt|gdoc|txt|rtf|mht|htm|html|mhtml|epub|docm|dot|dotm|dotx|fodt|ott|fb2|xml|oform|docxf|sxw|stw|wps|wpt|pages|hwp|hwpx|md|hml)|(vsdx|vssx|vstx|vsdm|vssm|vstm))$/
                                     .exec(_config.document.fileType);
                     if (!type) {
                         window.alert("The \"document.fileType\" parameter for the config object is invalid. Please correct it.");
@@ -551,7 +552,7 @@
 
                 _config.document.token = _config.token;
             }
-            
+
             return true;
         };
 
@@ -671,16 +672,6 @@
             });
         };
 
-        var _processSaveResult = function(result, message) {
-            _sendCommand({
-                command: 'processSaveResult',
-                data: {
-                    result: result,
-                    message: message
-                }
-            });
-        };
-
         // TODO: remove processRightsChange, use denyEditingRights
         var _processRightsChange = function(enabled, message) {
             _sendCommand({
@@ -905,7 +896,6 @@
 
         return {
             showMessage         : _showMessage,
-            processSaveResult   : _processSaveResult,
             processRightsChange : _processRightsChange,
             denyEditingRights   : _denyEditingRights,
             refreshHistory      : _refreshHistory,
@@ -955,7 +945,7 @@
     };
 
     DocsAPI.DocEditor.version = function() {
-        return '9.0.0';
+        return '9.1.0';
     };
 
     DocsAPI.DocEditor.warmUp = function(id) {
@@ -1073,7 +1063,8 @@
 
     function isLocalStorageAvailable() {
         try {
-            const storage = window['localStorage'];
+            localStorage.setItem('test', 'test');
+            localStorage.removeItem('test');
             return true;
         }
         catch(e) {
@@ -1310,7 +1301,7 @@
 
     function extendAppPath(config,  path) {
         if ( !config.isLocalFile ) {
-            const ver = '/9.0.0-{{HASH_POSTFIX}}';
+            const ver = '/9.1.0-{{HASH_POSTFIX}}';
             if ( ver.lastIndexOf('{{') < 0 && path.indexOf(ver) < 0 ) {
                 const pos = path.indexOf('/web-apps/app');
                 if ( pos > 0 )
